ozone <-
structure(list(upo3 = c(3, 5, 5, 6, 4, 4, 6, 7, 4, 6, 5, 4, 4, 
7, 5, 9, 4, 3, 4, 4, 5, 6, 9, 6, 6, 11, 10, 7, 12, 9, 2, 3, 3, 
2, 3, 3, 4, 6, 8, 6, 4, 3, 7, 11, 13, 6, 5, 4, 4, 6, 10, 15, 
23, 17, 7, 2, 3, 3, 4, 6, 7, 7, 6, 3, 2, 8, 12, 12, 16, 9, 24, 
13, 8, 10, 8, 9, 10, 14, 9, 11, 7, 9, 12, 12, 8, 9, 5, 4, 4, 
9, 13, 5, 10, 10, 7, 5, 4, 7, 3, 4, 7, 11, 15, 22, 17, 7, 10, 
19, 18, 12, 6, 9, 19, 21, 29, 16, 11, 2, 12, 16, 22, 20, 27, 
33, 25, 31, 18, 24, 16, 12, 9, 16, 8, 9, 29, 20, 5, 5, 11, 12, 
19, 17, 19, 16, 14, 10, 9, 7, 5, 2, 12, 22, 17, 26, 27, 14, 11, 
23, 26, 21, 15, 20, 15, 18, 26, 19, 13, 30, 26, 15, 16, 16, 19, 
23, 28, 34, 33, 24, 17, 10, 14, 13, 17, 22, 19, 20, 25, 28, 29, 
23, 26, 14, 13, 26, 22, 14, 13, 9, 12, 14, 24, 19, 16, 7, 2, 
4, 6, 12, 9, 15, 17, 13, 20, 22, 24, 26, 32, 33, 27, 38, 23, 
19, 19, 15, 28, 10, 14, 26, 17, 3, 14, 29, 18, 3, 9, 19, 8, 23, 
13, 7, 3, 5, 11, 12, 5, 4, 5, 4, 10, 17, 26, 30, 18, 12, 7, 15, 
12, 7, 28, 22, 18, 14, 24, 10, 14, 9, 12, 7, 7, 6, 13, 5, 3, 
7, 8, 10, 12, 6, 5, 20, 14, 16, 5, 3, 5, 1, 5, 4, 11, 6, 8, 14, 
18, 12, 9, 7, 14, 4, 3, 3, 3, 3, 3, 3, 3, 6, 6, 5, 3, 4, 7, 5, 
5, 4, 3, 2, 5, 3, 4, 4, 6, 6, 3, 4, 3, 8, 2, 3, 5, 1), vdht = c(5710, 
5700, 5760, 5720, 5790, 5790, 5700, 5700, 5770, 5720, 5760, 5780, 
5830, 5870, 5840, 5780, 5680, 5720, 5760, 5730, 5700, 5650, 5680, 
5820, 5810, 5790, 5800, 5820, 5770, 5670, 5590, 5410, 5350, 5480, 
5600, 5490, 5560, 5700, 5680, 5700, 5650, 5610, 5730, 5770, 5770, 
5690, 5700, 5730, 5690, 5640, 5720, 5740, 5740, 5740, 5670, 5550, 
5470, 5320, 5530, 5600, 5660, 5580, 5510, 5530, 5620, 5690, 5760, 
5740, 5780, 5790, 5760, 5700, 5680, 5720, 5720, 5730, 5710, 5720, 
5710, 5600, 5630, 5690, 5730, 5710, 5610, 5680, 5620, 5420, 5540, 
5590, 5690, 5550, 5620, 5630, 5580, 5560, 5440, 5480, 5620, 5450, 
5660, 5680, 5760, 5790, 5720, 5660, 5710, 5780, 5750, 5700, 5620, 
5650, 5730, 5810, 5790, 5740, 5690, 5680, 5650, 5730, 5730, 5760, 
5830, 5880, 5890, 5850, 5820, 5800, 5740, 5710, 5720, 5740, 5690, 
5730, 5780, 5790, 5750, 5680, 5720, 5770, 5800, 5780, 5740, 5730, 
5760, 5770, 5690, 5650, 5610, 5570, 5690, 5760, 5810, 5830, 5880, 
5860, 5830, 5870, 5860, 5800, 5800, 5770, 5860, 5870, 5870, 5860, 
5880, 5870, 5860, 5830, 5820, 5820, 5860, 5870, 5890, 5900, 5890, 
5910, 5900, 5860, 5830, 5850, 5830, 5810, 5830, 5830, 5840, 5870, 
5870, 5860, 5900, 5890, 5880, 5890, 5870, 5820, 5780, 5770, 5790, 
5840, 5910, 5890, 5870, 5780, 5730, 5780, 5750, 5760, 5730, 5730, 
5790, 5750, 5880, 5890, 5880, 5870, 5900, 5920, 5930, 5950, 5950, 
5900, 5890, 5860, 5840, 5800, 5760, 5810, 5850, 5760, 5860, 5830, 
5840, 5800, 5790, 5830, 5810, 5780, 5800, 5800, 5780, 5790, 5770, 
5750, 5640, 5640, 5650, 5710, 5760, 5840, 5880, 5890, 5890, 5890, 
5890, 5850, 5830, 5830, 5860, 5830, 5800, 5830, 5790, 5730, 5780, 
5740, 5710, 5690, 5670, 5760, 5820, 5790, 5760, 5800, 5810, 5750, 
5840, 5920, 5860, 5840, 5810, 5770, 5710, 5500, 5660, 5700, 5810, 
5860, 5900, 5850, 5780, 5790, 5780, 5770, 5750, 5780, 5790, 5750, 
5670, 5760, 5770, 5810, 5810, 5870, 5830, 5760, 5680, 5780, 5810, 
5760, 5680, 5750, 5790, 5770, 5750, 5720, 5760, 5780, 5660, 5610, 
5640, 5680, 5650, 5710, 5680, 5630, 5730, 5690, 5650, 5550), 
    wdsp = c(4, 3, 3, 4, 6, 3, 3, 3, 8, 3, 6, 6, 3, 2, 5, 4, 
    5, 4, 3, 4, 5, 5, 3, 5, 5, 3, 2, 5, 8, 3, 3, 6, 7, 9, 7, 
    11, 10, 3, 5, 4, 5, 5, 5, 5, 3, 8, 3, 11, 7, 5, 6, 3, 3, 
    3, 7, 10, 7, 11, 3, 3, 7, 5, 5, 5, 9, 0, 4, 3, 5, 2, 3, 4, 
    4, 5, 5, 4, 5, 4, 3, 6, 4, 7, 6, 3, 6, 5, 6, 7, 5, 6, 6, 
    21, 7, 6, 7, 4, 5, 7, 5, 11, 6, 6, 4, 4, 5, 6, 5, 7, 7, 5, 
    9, 6, 5, 4, 4, 8, 4, 6, 8, 6, 3, 7, 6, 3, 6, 4, 6, 7, 3, 
    7, 8, 5, 9, 5, 3, 7, 3, 6, 3, 4, 4, 8, 6, 6, 6, 7, 8, 6, 
    3, 9, 5, 3, 5, 4, 6, 3, 6, 4, 3, 3, 4, 5, 4, 7, 4, 6, 5, 
    7, 4, 5, 5, 8, 6, 3, 6, 6, 5, 4, 5, 3, 3, 9, 6, 8, 4, 5, 
    7, 6, 4, 3, 3, 4, 4, 6, 8, 6, 6, 3, 4, 7, 5, 5, 6, 7, 5, 
    7, 7, 5, 7, 5, 4, 3, 3, 7, 4, 7, 6, 4, 3, 5, 8, 5, 8, 7, 
    5, 6, 7, 6, 4, 7, 4, 5, 5, 7, 3, 5, 5, 6, 6, 5, 9, 8, 5, 
    4, 5, 7, 3, 6, 6, 4, 3, 5, 4, 5, 6, 3, 5, 8, 5, 5, 7, 4, 
    5, 4, 5, 7, 8, 6, 4, 4, 5, 3, 5, 6, 7, 4, 0, 3, 7, 0, 2, 
    2, 4, 9, 3, 3, 5, 0, 0, 5, 3, 0, 2, 2, 2, 5, 5, 6, 8, 0, 
    4, 2, 2, 3, 2, 0, 0, 4, 3, 0, 0, 0, 5, 3, 0, 0, 3, 0, 4, 
    2, 0, 3, 5, 4, 4, 4, 3, 3, 3, 4), hmdt = c(28, 37, 51, 69, 
    19, 25, 73, 59, 27, 44, 33, 19, 19, 19, 19, 59, 73, 19, 19, 
    26, 59, 70, 64, 19, 19, 28, 32, 19, 76, 69, 76, 64, 62, 72, 
    76, 72, 72, 32, 50, 86, 61, 62, 66, 68, 82, 21, 19, 19, 19, 
    68, 63, 54, 47, 56, 61, 74, 46, 45, 43, 21, 57, 42, 50, 61, 
    61, 60, 31, 66, 53, 42, 60, 82, 57, 21, 19, 32, 77, 71, 19, 
    45, 44, 70, 45, 46, 50, 69, 67, 69, 54, 51, 63, 63, 57, 61, 
    78, 65, 44, 51, 73, 35, 35, 61, 50, 57, 68, 58, 65, 78, 73, 
    41, 47, 46, 61, 55, 60, 78, 71, 77, 66, 74, 78, 78, 75, 80, 
    88, 76, 63, 78, 74, 63, 62, 53, 62, 71, 68, 79, 76, 71, 66, 
    81, 72, 92, 71, 64, 68, 59, 67, 66, 61, 81, 63, 58, 68, 71, 
    67, 64, 64, 69, 77, 61, 69, 64, 33, 38, 54, 39, 43, 55, 77, 
    63, 65, 64, 68, 76, 71, 86, 65, 73, 69, 64, 63, 72, 82, 69, 
    74, 69, 72, 73, 90, 80, 73, 71, 78, 80, 74, 63, 57, 55, 65, 
    65, 72, 79, 62, 65, 77, 70, 58, 58, 72, 77, 57, 67, 73, 70, 
    73, 73, 71, 77, 68, 62, 61, 71, 77, 71, 67, 74, 65, 82, 67, 
    87, 71, 77, 78, 72, 71, 71, 76, 76, 73, 80, 73, 80, 75, 68, 
    93, 57, 70, 65, 66, 73, 77, 80, 73, 19, 19, 73, 76, 77, 86, 
    76, 66, 74, 71, 84, 74, 48, 75, 74, 67, 75, 71, 35, 23, 19, 
    59, 60, 38, 22, 19, 45, 47, 73, 67, 56, 54, 71, 59, 25, 24, 
    41, 50, 76, 82, 81, 85, 76, 66, 58, 19, 19, 19, 19, 19, 19, 
    27, 64, 52, 19, 19, 32, 58, 26, 19, 19, 19, 19, 19, 19, 19, 
    58, 51, 52, 19, 19, 57, 50, 53, 23, 61, 85), sbtp = c(40, 
    45, 54, 35, 45, 55, 41, 44, 54, 51, 51, 54, 58, 61, 64, 67, 
    52, 54, 54, 58, 69, 51, 53, 59, 64, 63, 63, 62, 63, 54, 36, 
    31, 30, 36, 42, 37, 41, 46, 51, 55, 41, 41, 49, 45, 55, 41, 
    45, 51, 53, 50, 60, 54, 53, 53, 44, 40, 30, 25, 40, 45, 51, 
    48, 45, 47, 43, 49, 56, 53, 61, 63, 70, 57, 35, 52, 59, 67, 
    57, 42, 55, 40, 39, 57, 58, 62, 51, 61, 34, 35, 35, 48, 59, 
    41, 58, 51, 46, 40, 35, 46, 39, 32, 47, 50, 65, 66, 69, 59, 
    64, 68, 49, 52, 56, 55, 66, 74, 76, 70, 67, 41, 61, 68, 69, 
    74, 74, 80, 84, 78, 80, 76, 74, 66, 66, 69, 62, 67, 80, 76, 
    65, 65, 63, 62, 68, 68, 69, 66, 70, 70, 64, 61, 52, 48, 59, 
    67, 66, 74, 83, 78, 75, 84, 81, 79, 79, 65, 81, 84, 83, 90, 
    90, 93, 88, 72, 72, 70, 78, 87, 91, 87, 91, 88, 83, 78, 79, 
    77, 81, 76, 78, 75, 82, 84, 86, 80, 80, 84, 84, 81, 85, 73, 
    72, 68, 65, 79, 81, 80, 76, 59, 55, 66, 64, 62, 67, 74, 74, 
    70, 77, 83, 81, 73, 87, 89, 92, 92, 93, 93, 86, 76, 81, 78, 
    73, 80, 81, 52, 63, 72, 75, 55, 61, 71, 71, 72, 75, 65, 61, 
    60, 64, 61, 63, 62, 59, 56, 59, 72, 71, 75, 71, 71, 73, 78, 
    73, 71, 73, 71, 66, 69, 69, 64, 65, 54, 62, 56, 55, 58, 48, 
    54, 57, 60, 61, 63, 65, 71, 70, 68, 69, 59, 49, 39, 50, 46, 
    54, 60, 62, 65, 66, 66, 63, 62, 60, 63, 60, 58, 34, 36, 44, 
    53, 52, 53, 58, 55, 50, 48, 51, 62, 40, 44, 49, 53, 53, 53, 
    55, 51, 54, 48, 53, 49, 48, 51, 47, 50, 51, 51, 50, 39), 
    ibht = c(2693, 590, 1450, 1568, 2631, 554, 2083, 2654, 5000, 
    111, 492, 5000, 1249, 5000, 5000, 639, 393, 5000, 5000, 5000, 
    3044, 3641, 111, 597, 1791, 793, 531, 419, 816, 3651, 5000, 
    5000, 1341, 5000, 3799, 5000, 5000, 5000, 5000, 2398, 5000, 
    4281, 1161, 2778, 442, 5000, 5000, 5000, 5000, 5000, 1341, 
    1318, 885, 360, 3497, 5000, 5000, 5000, 5000, 5000, 5000, 
    3608, 5000, 5000, 5000, 613, 334, 567, 488, 531, 508, 1571, 
    721, 505, 377, 442, 902, 1381, 5000, 5000, 1302, 1292, 5000, 
    472, 1404, 944, 5000, 5000, 5000, 5000, 2014, 5000, 5000, 
    524, 5000, 5000, 5000, 2490, 5000, 5000, 5000, 1144, 547, 
    413, 610, 3638, 3848, 1479, 1108, 869, 5000, 5000, 1148, 
    856, 807, 2040, 314, 5000, 1410, 360, 1568, 1184, 898, 436, 
    774, 1181, 1991, 1597, 1184, 3005, 2880, 2125, 3720, 4337, 
    2053, 1958, 3644, 1368, 3539, 2785, 984, 1804, 3234, 3441, 
    1578, 1850, 2962, 2670, 5000, 5000, 5000, 987, 1148, 898, 
    777, 1279, 1046, 1167, 987, 1144, 977, 770, 629, 337, 590, 
    400, 580, 646, 826, 823, 2116, 2972, 2752, 1377, 1486, 990, 
    508, 1204, 2414, 2385, 2326, 3389, 2818, 2394, 2746, 2493, 
    1528, 111, 1899, 1289, 984, 836, 826, 1105, 1023, 2956, 2988, 
    4291, 3330, 1233, 1069, 984, 1653, 3930, 5000, 5000, 4212, 
    5000, 5000, 1545, 994, 1125, 636, 748, 692, 807, 869, 800, 
    393, 557, 620, 1404, 898, 377, 528, 2818, 3247, 895, 721, 
    5000, 1965, 1853, 2342, 5000, 4028, 2716, 3671, 3795, 3120, 
    2667, 5000, 5000, 308, 2982, 5000, 5000, 5000, 5000, 3070, 
    830, 711, 1049, 511, 5000, 5000, 377, 862, 337, 492, 1394, 
    3146, 2234, 2109, 5000, 2270, 2191, 3448, 5000, 5000, 2719, 
    1899, 5000, 5000, 5000, 2385, 1938, 590, 328, 5000, 597, 
    469, 1541, 5000, 5000, 5000, 5000, 5000, 5000, 5000, 2014, 
    436, 830, 1112, 1210, 501, 875, 1601, 5000, 5000, 5000, 2280, 
    2047, 5000, 3720, 311, 2536, 1154, 2933, 3064, 826, 5000, 
    111, 5000, 5000, 5000, 5000, 948, 5000, 5000, 3687, 5000, 
    5000, 5000, 5000, 508, 2851, 111, 5000, 3704, 5000), dgpg = c(-25, 
    -24, 25, 15, -33, -28, 23, -2, -19, 9, -44, -44, -53, -67, 
    -40, 1, -68, -66, -58, -26, 18, 23, -10, -52, -15, -15, -38, 
    -29, -7, 62, 70, 28, 18, 0, -18, 32, -1, -30, -8, 21, 51, 
    42, 27, 2, 26, -30, -53, -43, 7, 24, 19, 2, -4, 3, 73, 73, 
    44, 39, -12, -2, 30, 24, 38, 56, 66, -27, -9, 13, -20, -15, 
    7, 68, 28, -49, -27, -9, 54, 4, -16, 38, 40, -5, -14, 34, 
    42, 35, 75, 41, 62, 44, 31, 56, 27, 57, 55, 59, 24, 29, 107, 
    36, 28, 30, 1, 10, 46, 81, 45, 40, 55, 0, 43, 49, 31, 4, 
    16, 46, 60, 75, 20, 23, 32, 40, 24, 0, 6, 50, 47, 56, 52, 
    58, 53, 64, 74, 66, 31, 70, 86, 75, 73, 49, 26, 56, 77, 67, 
    61, 76, 80, 54, 76, 57, 46, 28, 43, -24, -1, 75, 69, 50, 
    45, 57, 60, 26, -11, -14, 26, 19, 9, 25, 41, 52, 47, 52, 
    41, 37, 33, 22, 29, 56, 63, 67, 64, 56, 58, 54, 61, 55, 42, 
    40, 45, 32, 35, 28, 27, 39, 46, 46, 56, 60, 59, 30, 28, 57, 
    71, 68, 73, 45, 46, 52, 31, 43, 44, 55, 16, 32, 44, 39, 19, 
    24, 6, 0, 27, 33, 21, -2, 17, 26, 10, 0, 0, 39, 13, 10, 7, 
    56, 35, 26, 31, 31, 35, 17, 39, 36, 25, 18, 30, 25, 38, 35, 
    13, 0, -9, -10, -39, -40, -34, -3, 27, -17, -2, 13, 27, 11, 
    21, 23, -7, -13, 12, 13, 11, 25, 21, -41, -21, -19, 10, 0, 
    -11, -40, -29, -22, -4, 18, 24, 15, 27, 54, -28, -38, -36, 
    -20, 1, 3, -8, -17, -22, -15, 7, 59, -63, -52, -54, -43, 
    -69, -50, -24, 28, -22, -40, -33, -16, 2, -52, -48, -37, 
    -26, -31, -48, -50, -22, -10, 0, -19, -28, -25, -10, -5, 
    -14, -36, 18, 8), ibtp = c(87, 128, 139, 121, 123, 182, 114, 
    91, 92, 173, 181, 135, 243, 186, 174, 189, 210, 126, 111, 
    111, 116, 87, 153, 214, 182, 188, 244, 243, 190, 95, 33, 
    2, 77, 37, 77, 34, 31, 77, 75, 121, 24, 52, 116, 132, 146, 
    57, 66, 95, 95, 56, 151, 181, 195, 195, 97, 45, -15, -25, 
    9, 39, 56, 41, 5, 20, 13, 154, 180, 166, 183, 217, 192, 135, 
    130, 196, 229, 243, 158, 135, 100, 83, 115, 120, 115, 172, 
    125, 132, 18, -6, 8, 56, 119, 29, 87, 126, 36, 18, 3, 86, 
    -4, 8, 41, 120, 194, 209, 176, 107, 138, 200, 186, 145, 35, 
    33, 160, 241, 228, 175, 150, 49, 129, 169, 198, 204, 230, 
    302, 300, 266, 209, 200, 208, 151, 141, 150, 105, 152, 227, 
    214, 152, 147, 120, 174, 207, 200, 171, 161, 160, 160, 152, 
    130, 56, 49, 107, 177, 194, 255, 281, 220, 204, 235, 243, 
    218, 215, 242, 302, 321, 295, 285, 307, 318, 291, 236, 213, 
    180, 211, 258, 266, 295, 296, 266, 247, 213, 218, 204, 221, 
    209, 208, 225, 233, 256, 247, 240, 260, 275, 263, 234, 251, 
    196, 187, 168, 148, 214, 235, 230, 204, 151, 109, 107, 138, 
    99, 141, 187, 209, 200, 233, 250, 254, 260, 261, 298, 332, 
    326, 298, 293, 270, 285, 260, 226, 196, 256, 268, 110, 161, 
    216, 219, 109, 128, 176, 188, 194, 194, 175, 115, 94, 204, 
    155, 115, 107, 87, 88, 156, 223, 242, 261, 288, 198, 208, 
    260, 231, 273, 279, 239, 178, 193, 209, 125, 205, 204, 148, 
    94, 97, 138, 167, 114, 105, 124, 158, 170, 211, 270, 165, 
    231, 221, 173, 55, 54, 70, 60, 120, 175, 156, 211, 213, 189, 
    191, 199, 216, 205, 167, 55, 28, 50, 132, 175, 136, 163, 
    211, 136, 164, 155, 171, 182, 61, 201, 126, 131, 106, 108, 
    215, 105, 92, 83, 68, 76, 74, 91, 148, 100, 225, 107, 83, 
    44), vsty = c(250, 100, 60, 60, 100, 250, 120, 120, 120, 
    150, 40, 200, 250, 200, 200, 150, 10, 140, 250, 200, 150, 
    140, 50, 70, 150, 120, 40, 120, 6, 30, 100, 200, 60, 350, 
    250, 350, 300, 300, 300, 200, 100, 250, 200, 200, 40, 300, 
    300, 300, 300, 300, 150, 150, 80, 40, 40, 80, 300, 200, 140, 
    140, 140, 100, 140, 200, 120, 300, 300, 150, 2, 50, 70, 17, 
    140, 140, 300, 200, 250, 60, 100, 150, 150, 200, 100, 300, 
    120, 100, 200, 200, 200, 300, 300, 250, 120, 140, 200, 140, 
    80, 300, 100, 300, 200, 120, 100, 120, 60, 120, 100, 100, 
    27, 40, 140, 150, 100, 100, 120, 150, 120, 120, 140, 120, 
    70, 80, 70, 40, 20, 17, 40, 50, 70, 80, 120, 100, 120, 200, 
    120, 40, 70, 100, 120, 100, 120, 70, 80, 100, 100, 120, 120, 
    120, 150, 140, 140, 140, 140, 60, 30, 17, 80, 60, 100, 120, 
    150, 120, 140, 140, 120, 120, 80, 140, 140, 150, 120, 120, 
    140, 100, 50, 40, 100, 100, 60, 50, 70, 80, 80, 90, 120, 
    120, 100, 60, 40, 40, 70, 80, 80, 80, 80, 120, 150, 200, 
    150, 100, 80, 70, 60, 150, 200, 200, 200, 250, 300, 70, 300, 
    150, 300, 30, 100, 100, 17, 20, 4, 70, 30, 70, 60, 40, 50, 
    70, 140, 100, 120, 150, 50, 70, 40, 70, 140, 140, 100, 70, 
    40, 100, 120, 120, 140, 120, 70, 150, 200, 200, 200, 70, 
    40, 50, 17, 80, 250, 200, 2, 20, 7, 30, 50, 70, 17, 80, 50, 
    60, 60, 80, 50, 50, 40, 40, 300, 200, 150, 100, 100, 150, 
    300, 30, 50, 20, 200, 120, 300, 200, 70, 140, 150, 200, 4, 
    40, 30, 30, 2, 0, 30, 60, 150, 100, 250, 150, 200, 200, 200, 
    80, 60, 300, 200, 300, 50, 40, 70, 150, 150, 70, 200, 120, 
    150, 150, 60, 70, 150, 300, 100, 70, 200, 70, 40, 100), day = c(3, 
    4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 
    20, 21, 22, 23, 24, 25, 27, 29, 30, 31, 32, 33, 34, 35, 36, 
    37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 51, 52, 
    53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 65, 66, 67, 68, 
    69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 
    85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
    100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 
    112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 
    125, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 138, 
    139, 140, 141, 143, 145, 146, 147, 148, 149, 150, 151, 152, 
    153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 
    165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 
    177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 
    189, 191, 192, 193, 194, 195, 196, 198, 199, 200, 201, 202, 
    203, 205, 206, 207, 208, 209, 210, 213, 214, 215, 216, 222, 
    224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 
    236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 
    248, 249, 250, 251, 252, 255, 256, 257, 258, 259, 261, 262, 
    263, 265, 266, 268, 269, 270, 271, 272, 273, 274, 275, 276, 
    277, 278, 279, 280, 281, 282, 283, 284, 285, 286, 287, 288, 
    289, 290, 291, 292, 293, 294, 295, 296, 297, 298, 299, 300, 
    301, 302, 303, 304, 305, 308, 310, 312, 314, 315, 316, 317, 
    318, 319, 320, 321, 322, 323, 324, 325, 326, 327, 328, 329, 
    330, 331, 332, 333, 334, 335, 336, 337, 338, 339, 340, 341, 
    342, 343, 344, 345, 346, 347, 348, 349, 350, 351, 352, 353, 
    354, 355, 356, 357, 358, 359, 362, 363, 364, 365)), .Names = c("upo3", 
"vdht", "wdsp", "hmdt", "sbtp", "ibht", "dgpg", "ibtp", "vsty", 
"day"), row.names = c(NA, 330L), class = "data.frame")
